#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

package Vhffs::Functions;
require Exporter;
@ISA    = qw(Exporter);
@EXPORT = qw( send_mail mail_template);

use strict;
use DBI;
use POSIX qw(locale_h);
use locale;
use Locale::gettext;
use Vhffs::Constants;

my $password;
srand(time ^ $$);

sub hash_mxdomain
{
	my $domain = shift;
	my $path = "";

	$path = substr( $domain , 0 , 1 ) . "/" . substr( $domain , 1 , 1 ) . "/" . $domain ;

	return( $path );
}


sub check_arg
{
    my $arg = shift;
    $arg =~ s/\'//g;
    return( $arg );
}


sub hash_popuser
{
	my $user = shift;
	my $path = "";

	$path = substr( $user , 0 , 1 ) . "/" . $user ;

	return( $path );
}

sub old_hash
{
	use Digest::MD5 qw(md5 md5_hex md5_base64);
	my $servername = shift;
	my $hash = md5_hex( $servername );
	my $webdir = substr( $hash , 0 , 2 ) . "/" . substr( $hash , 2 , 2 ) . "/" .substr( $hash , 4 , 2 ) . "/" . substr( $hash , 6 , 2 ) . "/" . substr( $hash , 8 , 2 ) . "/" . substr( $hash , 10 , 2 ) . "/" .substr( $hash , 12 , 2 ) . "/" .substr( $hash , 14 , 2 ) . "/" . substr( $hash , 16 , 2 ) . "/" .substr( $hash , 18 , 2 ) . "/" . substr( $hash , 20 , 2 ) . "/" . substr( $hash , 22 , 2 ) . "/" . substr( $hash , 24 , 2 ) . "/" .substr( $hash , 26 , 2 ) . "/" .substr( $hash , 28 , 2 ) .  "/" .substr( $hash , 30 , 2 ) .  "/" .$servername;

	return( $webdir );
}


sub hash_webdir
{
	use Digest::MD5 qw(md5 md5_hex md5_base64);
	my $servername = shift;
	my $hash = md5_hex( $servername );
	my $webdir = substr( $hash , 0 , 2 ) . "/" . substr( $hash , 2 , 2 ) . "/" .substr( $hash , 4 , 2 ) . "/" .$servername;

	return $webdir;
	
}

sub create_dir
{
	my $dir = shift;

	my $value;

	my @subdirs = split( /\// , $dir );
	@subdirs = reverse @subdirs;
                
	my $path = "";
               
	while( defined ( $value = pop ( @subdirs ) )  )
	{
		$path .= "/".$value if( $value ne '' );
		mkdir( $path ) if( ! -d $path );
	}
	return 1;
}


sub stripslashes
{
    my $string = shift;

    $string =~ s/\\//g;
    $string =~ s/\Q//g;

    return ( $string  );
}

sub addslashes
{
	my $string = shift;

	return( quotemeta( $string ) );
}


sub chmod_recur
{
    my $dir;
    my $fmod;
    my $dmod;

    $dir  = shift;
    $fmod = shift;
    $dmod = shift;

    if( -d $dir )
    {
	chmod( $dmod , $dir );
	opendir( DIR , $dir );
	my @files = readdir( DIR );
	my $file;
	my $cfile;

	foreach $file ( @files )
	{
	    next if( ( $file eq '.' ) or ( $file eq '..' ) );
	    $cfile = $dir . "/" . $file;
	    chmod_recur( $cfile , $fmod , $dmod );
	}

	close( DIR );
    }
    elsif( -f $dir )
    {
	chmod( $fmod , $dir );
    }
    
}

# Change the owner and groupe recursivly for a dir
sub change_owner_recur
{
    my $dir = shift;
    my $uid = shift;
    my $gid = shift;
    
    my $value; 
    if( -f $dir )
    {
	chown( $uid , $gid , $dir );
    }
    elsif( -d $dir )
    {
	chown( $uid , $gid , $dir );
	opendir( DIRECTORY , $dir );
	my @files = readdir( DIRECTORY );
	foreach $value ( @files )
	{
	     next if( $value eq "" );
	    next if( $value eq ".." );
	    next if( $value eq "." );
	    change_owner_recur( $dir . "/" . $value , $uid , $gid);
	}
	closedir( DIRECTORY );
    }
    
    return 1;
}



sub send_mail
{
	use MIME::Lite;
	#my (  $from , $to , $subject , $message ) = @_;
	my $from = shift;
	my $to = shift;
	my $subject = shift;
	my $message = shift;
	my $vhffs = shift;

	if( defined $vhffs )
	{
		my $mailtag = $vhffs->get_config->get_mailtag;

		if( defined $mailtag )
		{
			$subject = $mailtag . " " . $subject; 
		}
	}

    my $msg = new MIME::Lite
        From    => "$from", 
        To      => "$to",    
        Subject => "$subject",
        Type    => 'text/plain; charset=utf-8',  
        Data    => "$message";
    $msg -> send;

	return( 1 );
}

#Connect to the database
sub db_connect
{
    my $backend_config;
    my $dbparams;
    my $dbh;
    my $driver;
	my $port;
	my $host;


    ($backend_config) = @_;


	#Default port;

    if( $backend_config->{'driver'} =~  /pg/ )
    {
		$port 	= 5432;
    	$driver = "Pg";
		$host 	= "localhost";
		$port 	= $backend_config->{'db_port'} if( defined( $backend_config->{'db_port'} ) );
		$host 	= $backend_config->{'db_host'} if( defined( $backend_config->{'db_host'} ) );

		$dbparams = "dbname=$backend_config->{'db_name'};host=$host;port=$port";
        $dbh = DBI->connect("DBI:$driver:$dbparams",$backend_config->{'db_username'}, $backend_config->{'db_password'}) || (print STDERR "Cant connect: $DBI::errstr\n" and return undef);
	
        return( $dbh );
    }
    
    else
    {
        print "the backend you specify in your config file is not supported in Vhffs";
        exit -1;
    }
}

sub generate_random_password
{
    my $password;
    for (0 .. 7) { $password .= ('a'..'z', 'A'..'Z', '0'..'9')[int rand 62] ; }
    return $password;
}


sub password_encrypt
{
    #use Digest::HMAC_MD5;
    use Crypt::PasswdMD5;
    use Vhffs::Misc::Salt;

    my $password = shift;

    my $cryptedpassword = unix_md5_crypt($password, salt());
    return $cryptedpassword;
}



sub hash_homename
{
    my ( $chain , $path , $main );
    $chain = shift;
    $main = shift;
        
    return undef if( ! defined $main->get_config->get_datadir );

    $path = $main->get_config->get_datadir. "/home/" . substr( $chain , 0 , 
                   1 ) . "/" . substr( $chain , 1 , 1 ) . "/" . $chain;    

    return( $path );
}


sub hash_groupname
{
    my ( $chain , $path , $main );
    $chain = shift;
    $main = shift;
        
    return undef if( ! defined $main->get_config->get_datadir );

    $path = $main->get_config->get_datadir. "/groups/" . substr( $chain , 0 , 1 ) . "/" . substr( $chain , 1 , 1 ) . "/" . $chain;    

    return( $path );
}



sub parse_date
{
	my $string = shift;
    my $result = {};

    if( $string =~ /(\d+)\-(\d+)\-(\d+)\s(\d+):(\d+):(\d+).*/ )
    {
        $result->{year} = $1;
        $result->{month} = $2;
        $result->{day} = $3;
        $result->{hours} = $4;
        $result->{minutes} = $5;
        $result->{seconds} = $6;
    }
    else
    {
        return undef;
    }
    return $result;
}


sub valid_mail
{
	my $mail = shift;
	use Email::Valid;
	return 1 if( Email::Valid->rfc822 ( $mail ) );
	return -1;
}





sub status_string_from_status_id
{
	my $status = shift;

	if( $status == Vhffs::Constants::WAITING_FOR_VALIDATION )
	{
		return gettext("Waiting for validation");
	}
	elsif( $status == Vhffs::Constants::VALIDATION_REFUSED )
	{
		return gettext("Validation refused");
	}
	elsif( $status == Vhffs::Constants::WAITING_FOR_CREATION )
	{
		return gettext("Waiting for creation");
	}
	elsif( $status == Vhffs::Constants::CREATING_ERROR )
	{
		return gettext("Creating error");
	}
	elsif( $status == Vhffs::Constants::CREATED )
	{   
		return gettext("Created");
	}
	elsif( $status == Vhffs::Constants::ACTIVATED )
	{
		return gettext("Activated");
	}
	elsif( $status == Vhffs::Constants::SUSPENDED )
	{   
		return gettext("Suspended");
	}
	elsif( $status == Vhffs::Constants::SUSPENDED_BEFORE_DELETED )
	{
		return gettext("Suspended before deletion");
	}
	elsif( $status == Vhffs::Constants::WAITING_FOR_MODIFICATION )
	{
		return gettext("Waiting for modification");
	}
	elsif( $status == Vhffs::Constants::MODIFICATION_ERROR )
	{
		return gettext("Modification error");
	}
	elsif( $status == Vhffs::Constants::MODIFICATION_APPLIED )
	{
		return gettext("Modification applied");
	}
	elsif( $status == Vhffs::Constants::TO_DELETE )
	{
		return gettext("Will be deleted");
	}
}

sub mail_template
{
	my( $user , $keys , $template , $file , $content , $line , $key , $vhffs );
	$vhffs		= shift;
	$template 	= shift;
	$user 		= shift;
	$keys		= shift;

	$file = Vhffs::Constants::MAILS_DIR . "/" . $template;

	return( -1 ) if( $user->fetch != 1 );

	return( -1 ) if( ! -f $file );
	return( -1 ) if( ! -r $file );

	$content = "";

	open( FIC , $file );

	while( $line = <FIC> )
	{
		foreach $key ( keys %{$keys} )
		{
			$line =~ s/$key/$keys->{$key}/g;
		}
		$content .= $line;
	}

	if( send_mail( $keys->{FROM} , $user->get_mail , $keys->{SUBJECT} , $content , $vhffs ) != 1 )
	{
		return( -2 );
	}

	close( FIC );



	return( 1 );
}


sub rotate_log
{
	use File::Basename;

	my $path = shift;
	my $rotation = shift;
	my $compress = shift;
	my $dir = dirname ( $path );
	my $file = basename ( $path );

	return if ( ! -f $path );

	# remove files out of the rotation
	opendir ( DIR , $dir );
	my @files = readdir( DIR );
	foreach ( @files )
	{
		next if( $file ne substr($_, 0, length( $file ) ) );
		my $suffix = substr($_, length( $file ) );
		$suffix =~ s/^.//;
		$suffix =~ s/.gz$//;
		next if( ! ( $suffix =~ /\d+/ ) );
		unlink $dir."/".$_ if( $suffix >= $rotation-1 );
	}

	# rotate logs
	my $i;
	for ( $i = $rotation-2 ; $i >= 0 ; $i-- )  {
		my $j = $i +1;

		# found a file which is not compressed
		if ( -f $dir."/".$file.".".$i )  {

			# rotate it
			rename $dir."/".$file.".".$i , $dir."/".$file.".".$j ;
	
			# compress it if compression is enabled
			if ( $compress )  {
				my $cmd = "gzip ".$dir."/".$file.".".$j;
				system ( $cmd );
			}
		}
		# found a file which is already compressed
		elsif ( -f $dir."/".$file.".".$i.".gz" )  {

			# rotate it
			rename $dir."/".$file.".".$i.".gz" , $dir."/".$file.".".$j.".gz" ;

			# uncompress it if compression is disabled
			if ( ! $compress )  {
				my $cmd = "gzip -d ".$dir."/".$file.".".$j.".gz";
				system ( $cmd );
			}
		}
	}

	# last rotate, log -> log.0
	rename $dir."/".$file , $dir."/".$file.".0" ;

	# create an empty file (prevent re-using of file .0 in stats parser)
	open( EMPTYFILE , "> ".$dir."/".$file );
	print EMPTYFILE "";
	close( EMPTYFILE );
}

1;
