#!/usr/bin/perl -w 
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;


use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Stats;
use Vhffs::Constants;
my $panel = new Vhffs::Panel::Main();
if(!$panel)  {
        exit 0;
}

my $vhffs = $panel->{'vhffs'};
my $session = $panel->{'session'};
my $maintemplate = $panel->{'template'};
my $user = $panel->{'user'};
#my $group = $panel->{'group'};
my $projectname = $session->param("project");
my $cgi = $panel->{'cgi'};
my $username = $cgi->param("NAME");
my $template;

my $templatedir = $vhffs->get_config->get_templatedir;

my $object;

if( $user->is_admin != 1 )
{
	
	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	my $message = gettext( "You are not allowed to see it");
	$template->param( MESSAGE => $message );
}
elsif( ! defined $username )
{
	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	my $message = gettext( "CGI ERROR !");
	$template->param( MESSAGE => $message );
}
elsif( ( ! defined ( $object = new Vhffs::User( $vhffs , $username , '401' ) ) ) || ( $object->fetch < 0 ) )
{
	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	my $message = gettext( "Cannot fetch object");
	$template->param( MESSAGE => $message );
}
else
{
	$template = new HTML::Template( filename => $templatedir."/admin/user/edit.tmpl" );

	$template->param( TITLE => gettext("Edit User") );


	$template->param( TEXT_USERNAME => gettext("Username:") );
	$template->param( TEXT_FIRSTNAME => gettext("Firstname") );
	$template->param( TEXT_LASTNAME => gettext("Lastname") );
	$template->param( TEXT_SHELL => gettext("Shell") );
	$template->param( TEXT_PASSWD => gettext("Password") );
	$template->param( TEXT_HOMEDIR => gettext("Home") );
	$template->param( TEXT_ADMIN => gettext("Admin") );
	$template->param( TEXT_UID => gettext("UID") );
	$template->param( TEXT_GID => gettext("GID") );
	$template->param( TEXT_ADDRESS => gettext("Address") );
	$template->param( TEXT_CITY => gettext("City") );
	$template->param( TEXT_ZIPCODE => gettext("Zipcode") );
	$template->param( TEXT_COUNTRY => gettext("Country") );
	$template->param( TEXT_MAIL => gettext("Mail") );
	$template->param( TEXT_GPG => gettext("GPG key") );
	$template->param( TEXT_HISTORY => gettext("History") );
	$template->param( SEND => gettext("Send") );

	$template->param( VALUE_USERNAME => $object->get_username );
	$template->param( VALUE_FIRSTNAME => $object->get_firstname );
	$template->param( VALUE_LASTNAME => $object->get_lastname );
	$template->param( VALUE_SHELL => $object->get_shell );
	$template->param( VALUE_HOMEDIR => $object->get_home );
	$template->param( VALUE_ADDRESS => $object->get_address );
	$template->param( VALUE_MAIL => $object->get_mail );
	$template->param( VALUE_ZIPCODE => $object->get_zipcode );
	$template->param( VALUE_COUNTRY => $object->get_country );
	$template->param( VALUE_UID => $object->get_uid );
	$template->param( VALUE_GID => $object->get_gid );
	$template->param( VALUE_CITY => $object->get_city );

	$template->param( VALUE_MODERATOR_USER => Vhffs::Constants::USER_MODERATOR );
	$template->param( VALUE_NORMAL_USER  => Vhffs::Constants::USER_NORMAL );
	$template->param( VALUE_ADMIN_USER => Vhffs::Constants::USER_ADMIN );
	
	$template->param( TEXT_MODERATOR_USER => gettext("Moderator") );
	$template->param( TEXT_ADMIN_USER => gettext("Admin") );
	$template->param( TEXT_NORMAL_USER => gettext("Hosted") );

	my $oid = $object->{'object_id'};
	$template->param( VALUE_HISTORY => "/history.pl?OID=$oid" );

	$template->param( TEXT_STATUS => gettext("Status") );

    $template->param( TEXT_STATUS_WAITING_FOR_VALIDATION => gettext("Waiting for validation") );
    $template->param( TEXT_STATUS_VALIDATION_REFUSED => gettext("Validation refused") );
    $template->param( TEXT_STATUS_WAITING_FOR_CREATION => gettext("Waiting for creation") );
    $template->param( TEXT_STATUS_CREATING_ERROR => gettext("Creating error") );
    $template->param( TEXT_STATUS_ACTIVATED => gettext("Activated") );
    $template->param( TEXT_STATUS_CREATED => gettext("Created") );
    $template->param( TEXT_STATUS_SUSPENDED => gettext("Suspended") );
    $template->param( TEXT_STATUS_SUSPENDED_BEFORE_DELETED => gettext("Suspended before deletion") );
    $template->param( TEXT_STATUS_WAITING_FOR_MODIFICATION => gettext("Waiting for modification") );
    $template->param( TEXT_STATUS_MODIFICATION_ERROR => gettext("Modification error") );
    $template->param( TEXT_STATUS_MODIFICATION_APPLIED => gettext("Modification applied") );
    $template->param( TEXT_STATUS_TO_DELETE => gettext("Will be deleted") );


    $template->param( VALUE_STATUS_WAITING_FOR_VALIDATION => Vhffs::Constants::WAITING_FOR_VALIDATION );
    $template->param( VALUE_STATUS_VALIDATION_REFUSED => Vhffs::Constants::VALIDATION_REFUSED );
    $template->param( VALUE_STATUS_WAITING_FOR_CREATION => Vhffs::Constants::WAITING_FOR_CREATION );
    $template->param( VALUE_STATUS_CREATING_ERROR => Vhffs::Constants::CREATING_ERROR );
    $template->param( VALUE_STATUS_ACTIVATED => Vhffs::Constants::ACTIVATED );
    $template->param( VALUE_STATUS_CREATED => Vhffs::Constants::CREATED );
    $template->param( VALUE_STATUS_SUSPENDED => Vhffs::Constants::SUSPENDED );
    $template->param( VALUE_STATUS_SUSPENDED_BEFORE_DELETED => Vhffs::Constants::SUSPENDED_BEFORE_DELETED );
    $template->param( VALUE_STATUS_WAITING_FOR_MODIFICATION => Vhffs::Constants::WAITING_FOR_MODIFICATION );
    $template->param( VALUE_STATUS_MODIFICATION_ERROR => Vhffs::Constants::MODIFICATION_ERROR );
    $template->param( VALUE_STATUS_MODIFICATION_APPLIED => Vhffs::Constants::MODIFICATION_APPLIED );
    $template->param( VALUE_STATUS_TO_DELETE => Vhffs::Constants::TO_DELETE );

    my $status = $object->get_status;

    if( $status == Vhffs::Constants::WAITING_FOR_VALIDATION )
    {
        $template->param( SELECTED_STATUS_WAITING_FOR_VALIDATION => "selected" );
    }
    elsif( $status == Vhffs::Constants::VALIDATION_REFUSED )
    {
        $template->param( SELECTED_STATUS_VALIDATION_REFUSED => "selected" );
    }
    elsif( $status == Vhffs::Constants::WAITING_FOR_CREATION )
    {   
        $template->param( SELECTED_STATUS_WAITING_FOR_CREATION => "selected" );
    }
    elsif( $status == Vhffs::Constants::CREATING_ERROR )
    {   
        $template->param( SELECTED_STATUS_CREATING_ERROR => "selected" );
    }
    elsif( $status == Vhffs::Constants::CREATED )
    {   
        $template->param( SELECTED_STATUS_CREATED => "selected" );
    }
    elsif( $status == Vhffs::Constants::ACTIVATED )
    {   
        $template->param( SELECTED_STATUS_ACTIVATED => "selected" );
    }
    elsif( $status == Vhffs::Constants::SUSPENDED )
    {   
        $template->param( SELECTED_STATUS_SUSPENDED => "selected" );
    }
    elsif( $status == Vhffs::Constants::SUSPENDED_BEFORE_DELETED )
    {
        $template->param( SELECTED_STATUS_SUSPENDED_BEFORE_DELETED => "selected" );
    }
    elsif( $status == Vhffs::Constants::WAITING_FOR_MODIFICATION )
    {
        $template->param( SELECTED_STATUS_WAITING_FOR_MODIFICATION => "selected" );
    }
    elsif( $status == Vhffs::Constants::MODIFICATION_ERROR )
    {
        $template->param( SELECTED_STATUS_MODIFICATION_ERROR => "selected" );
    }
    elsif( $status == Vhffs::Constants::MODIFICATION_APPLIED )
    {
        $template->param( SELECTED_STATUS_MODIFICATION_APPLIED => "selected" );
    }
    elsif( $status == Vhffs::Constants::TO_DELETE )
    {
        $template->param( SELECTED_STATUS_TO_DELETE => "selected" );
    }


	my $groups = Vhffs::Group::getall_by_user( $vhffs , undef , $object );
    my $g;
    my $subtemplate;
    my $tmp = "";
    foreach $g ( @{$groups} )
    {
        $subtemplate = new HTML::Template( filename => $templatedir."/admin/user/group-part.tmpl" );
        $subtemplate->param( GROUPNAME => $g->get_groupname );
        $subtemplate->param( OWNER_TEXT => gettext("Owner of this group") );
        $subtemplate->param( OWNER => $g->get_owner_username );
        $subtemplate->param( STATE => Vhffs::Functions::status_string_from_status_id( $g->get_status) );

        $tmp .= $subtemplate->output;
    }

    $template->param( TEXT_GROUPS => gettext("Groups of this user") );
    $template->param( GROUPS => $tmp );


	if( $object->is_moderator )
	{
		$template->param( SELECTED_MODERATOR_USER => "selected" );
	}
	elsif( $object->is_admin )
	{
		$template->param( SELECTED_ADMIN_USER => "selected" );
	}
	else
	{
		$template->param( SELECTED_NORMAL_USER => "selected" );
	}




	if( $vhffs->get_config->use_notation == 1 )
	{
		use Vhffs::Note;
		my $subtemplate = new HTML::Template( filename => $templatedir."/admin/user/edit-note.tmpl" );
		$subtemplate->param( TEXT_NOTE => "Note" );
		$subtemplate->param( VALUE_NOTE => Vhffs::Note::get_note( $vhffs , $object ) );
		$subtemplate->param( VALUE_USERNAME => $object->get_username );
		$subtemplate->param( SEND => gettext("Update note") );

		$template->param( NOTE => $subtemplate->output );
	}



}


display Vhffs::Panel::Main($panel, $template->output);
