#!/usr/bin/perl -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;

use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Services::Mail;
use Vhffs::Acl;
use Vhffs::Constants;
my $panel = new Vhffs::Panel::Main();
if(!$panel)  {
        exit 0;
}

my $vhffs = $panel->{'vhffs'};
my $session = $panel->{'session'};
my $maintemplate = $panel->{'template'};
my $user = $panel->{'user'};
my $group = $panel->{'group'};
my $projectname = $session->param("project");
my $cgi = $panel->{'cgi'};
my $domain = $cgi->param("DOMAIN");
my $boxname = $cgi->param("LOCALPART");
my $password = $cgi->param("PASSWORD");
my $template;
my $message;
my $mail = new Vhffs::Services::Mail( $vhffs , $domain , $user , $group );

my $templatedir = $vhffs->get_config->get_templatedir;

my $retour;

if( ! defined $mail )
{
	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	$message = sprintf( gettext("Cannot instanciate object %s"), $domain );
	$template->param( MESSAGE => $message );
}
elsif( $mail->fetch < 0 )
{

	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	$message = gettext( "Cannot get informations on this object");
	$template->param( MESSAGE => $message );

}
elsif( ! defined $boxname ) 
{
	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	$message = gettext( "CGI ERROR");
	$template->param( MESSAGE => $message );
}
elsif( $mail->get_status != Vhffs::Constants::ACTIVATED )
{
	
	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	$message = gettext( "This object is not functionnal yet. Please wait creation or moderation.");
	$template->param( MESSAGE => $message );
}
elsif( ( Vhffs::Acl::what_perm_for_user( $user , $mail , $vhffs ) < Vhffs::Constants::ACL_VIEW ) && ( $user->is_admin != 1 ) )
{
	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	$message = gettext("You're not allowed to do this (ACL rights)");
	$template->param( MESSAGE => $message );
}
elsif( $vhffs->get_config->use_novirus != 1 )
{
	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	$message = gettext("Virus protection is not allowed");
	$template->param( MESSAGE => $message );
}
else
{
	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );

	if( ( $retour = $mail->change_virus_status( $boxname ) ) < 0 )
	{
		$message = gettext( "Error when applying changes" );
	}
	else
	{
		if( $mail->commit < 0 )
		{
			$message = gettext( "Unable to reccord changes on this domain" );
		}
		else
		{
			$message = sprintf(gettext( "Virus status updated for box %s" ) , $boxname );
		}
	}
	$template->param( MESSAGE => $message );
}

set_refresh_url Vhffs::Panel::Main($panel, "/mail/prefs.pl?name=$domain", 0);
display Vhffs::Panel::Main($panel, $template->output);
