#!/usr/bin/perl -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;

use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Services::Mailing;
use Vhffs::Acl;
use Vhffs::Constants;
my $panel = new Vhffs::Panel::Main();
if(!$panel)  {
        exit 0;
}

my $vhffs = $panel->{'vhffs'};
my $session = $panel->{'session'};
my $maintemplate = $panel->{'template'};
my $user = $panel->{'user'};
my $group = $panel->{'group'};
my $projectname = $session->param("project");
my $cgi = $panel->{'cgi'};
my $domain = $cgi->param("domain");
my $lpart = $cgi->param("local");
my $name = $cgi->param("name");
my $template;
my $subtemplate;
my $templatedir = $vhffs->get_config->get_templatedir;

my $num_members;
$num_members = 0;

#defined name in CGI overwrite lpart and domain cgi
if( defined $name )
{
	( $lpart , $domain ) =  ( $name =~ /(.+)\@(.+)/ );

}

my $list = new Vhffs::Services::Mailing( $vhffs , $lpart , $domain , $user , $group );


if( ( ! defined $list ) || ( $list->fetch < 0 ) )
{

	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	my $message = gettext( "Cannot get informations on this object".$lpart."/".$domain);
	$template->param( MESSAGE => $message );

}
elsif( ( $list->get_status != Vhffs::Constants::ACTIVATED ) && ( $user->is_admin != 1 ) )
{
	
	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	my $message = gettext( "This object is not functionnal yet. Please wait creation or moderation.");
	$template->param( MESSAGE => $message );
}
elsif( ( Vhffs::Acl::what_perm_for_user( $user , $list , $vhffs ) < Vhffs::Constants::ACL_VIEW ) && ( $user->is_admin != 1 ) )
{
	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	my $message = gettext("You're not allowed to do this (ACL rights)");
	$template->param( MESSAGE => $message );
}
else
{
	$template = new HTML::Template( filename => $templatedir."/mailinglist/prefs.tmpl" );

	$template->param( TEXT_TITLE => gettext("Administration for list ") );
	$template->param( VALUE_LIST => $list->get_localpart . "\@" . $list->get_domain );
	$template->param( VALUE_DOMAIN => $list->get_domain );
	$template->param( VALUE_LOCALPART => $list->get_localpart );
	
	$template->param( SUBTITLE_OPTIONS => gettext("Options") );
	$template->param( TEXT_MODERATED => gettext("Moderated") );
	$template->param( TEXT_OPENPOST => gettext("Open post") );
	$template->param( TEXT_OPENSUB => gettext("Open subscribing") );
	$template->param( TEXT_OPENARCHIVE => gettext("Open archives") );
	$template->param( TEXT_REPLYTO => gettext("Reply to: on list") );
	$template->param( TEXT_PREFIX  => gettext("Prefix on subject") );
	$template->param( VALUE_PREFIX  => $list->get_prefix );

	$template->param( TEXT_SUBMIT_PREFS => gettext("Save options") );
	
	$template->param( TITLE_MEMBERS => gettext("Manage members") );
	$template->param( TITLE_LIST_MEMBERS => gettext("List all members") );
	$template->param( TITLE_ADD_MEMBER => gettext("Add a member") );
	$template->param( TEXT_ADD_MEMBER => gettext("Email adress") );
	$template->param( BUTTON_ADD_MEMBER => gettext("Add !") );


	if( $list->get_open_archive == 1 ) 
	{
		$template->param( CHECK_OPENARCHIVE => "checked" );
	}
	if( $list->get_open_sub == 1 ) 
	{
		$template->param( CHECK_OPENSUB => "checked" );
	}


	if( $list->get_open_post == 1 ) 
	{
		$template->param( CHECK_OPENPOST => "checked" );
	}

	if( $list->get_replyto == 1 ) 
	{
		$template->param( CHECK_REPLYTO => "checked" );
	}

	if( $list->get_moderated == 1 ) 
	{
		$template->param( CHECK_MODERATED => "checked" );
	}

	my $subs = $list->get_members;
	my $output = "";
	if( defined $subs )
	{
		foreach( keys %{$subs} )
		{
			$subtemplate = new HTML::Template( filename => $templatedir."/mailinglist/list_part.tmpl" );
			$subtemplate->param( BUTTON_DELETE_MEMBER   => gettext("Delete from list") );
			$subtemplate->param( BUTTON_CHANGE_RIGHT    => gettext("Change rights\n") );
			$subtemplate->param( MEMBER                 => $subs->{$_}{member} );
			$subtemplate->param( VALUE_LOCALPART        => $list->get_localpart );
			$subtemplate->param( VALUE_DOMAIN           => $list->get_domain );
	
			$subtemplate->param( VALUE_RIGHT_SUB                       => Vhffs::Constants::ML_RIGHT_SUB );
			$subtemplate->param( VALUE_RIGHT_SUB_WAITING_FOR_REPLY     => Vhffs::Constants::ML_RIGHT_SUB_WAITING_FOR_REPLY );
			$subtemplate->param( VALUE_RIGHT_SUB_WAITING_FOR_DELETE    => Vhffs::Constants::ML_RIGHT_SUB_WAITING_FOR_DEL);
			$subtemplate->param( VALUE_RIGHT_ADMIN                     => Vhffs::Constants::ML_RIGHT_ADMIN );

			$subtemplate->param( TEXT_RIGHT_SUB                        => gettext( "Subscriber" ) );
			$subtemplate->param( TEXT_RIGHT_SUB_WAITING_FOR_REPLY      => gettext( "Subscribed. Waiting for confirmation" ) );
			$subtemplate->param( TEXT_RIGHT_SUB_WAITING_FOR_DELETE      => gettext( "Waiting for delete" ) );

			$subtemplate->param( TEXT_RIGHT_ADMIN                      => gettext( "Admin"  ) );

			$subtemplate->param( SELECTED_RIGHT_ADMIN                  => "selected" ) if( $subs->{$_}{perm} == Vhffs::Constants::ML_RIGHT_ADMIN );
			$subtemplate->param( SELECTED_RIGHT_SUB_WAITING_FOR_DELETE => "selected" ) if( $subs->{$_}{perm} == Vhffs::Constants::ML_RIGHT_SUB_WAITING_FOR_DEL );
			$subtemplate->param( SELECTED_RIGHT_SUB                    => "selected" ) if( $subs->{$_}{perm} == Vhffs::Constants::ML_RIGHT_SUB );
			$subtemplate->param( SELECTED_RIGHT_SUB_WAITING_FOR_REPLY  => "selected" ) if( $subs->{$_}{perm} == Vhffs::Constants::ML_RIGHT_SUB_WAITING_FOR_REPLY );
	
			$output .= $subtemplate->output;	
			$num_members++;
		}
		$template->param( LIST_MEMBERS => $output );
		$template->param( HOWMANY_MEMBERS => $num_members );
	}
	else
	{
		$template->param( LIST_MEMBERS => gettext( "No member on this list" ) );
	}


	$template->param( TEXT_DELETE_LIST => gettext("Delete this list") );
	$template->param( TEXT_BEFORE_DELETE => gettext("This action is non-reversible. All services associated to this project will be DESTROYED.") );
	$template->param( ASK_DELETE_WEB => gettext("Are you SURE you want DELETE this Mail Area ?") );
	$template->param( YES => gettext("Yes I'm sure of what I do") );
	$template->param( NO => gettext("No, I'm not sure, I prefer to keep this project.") );
	$template->param( TEXT_DELETE => gettext("Delete") );

    $template->param( TEXT_ACL_ADMIN => "Admin Rights on this object (ACL)" );
    $template->param( EXPLAIN_ADMIN_ACL => "You can Manage rights on this service for each user in the VHFFS database. Please read help before manage it." );
    $template->param( ADMIN_ACL => "Ok, go to ACL admin" );

    if( $user->is_admin == 1 )
    {
            $subtemplate = new HTML::Template( filename => $templatedir."/admin/misc/opart.tmpl" );
            $subtemplate->param( OID => $list->get_oid );
            $subtemplate->param( OPART_TEXT => gettext("Go to object-part admin") );
            $subtemplate->param( OPART_TITLE => gettext("Object part") );
            $template->param( OPART => $subtemplate->output );
    }


}

display Vhffs::Panel::Main($panel, $template->output);
