#!/usr/bin/perl -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;

use Vhffs::User;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;

my $panel = new Vhffs::Panel::Main();
if(!$panel)  {
        exit 0;
}

my $vhffs = $panel->{'vhffs'};
my $session = $panel->{'session'};
my $maintemplate = $panel->{'template'};
my $user = $panel->{'user'};
my $cgi = $panel->{'cgi'};
my $su_user = $cgi->param('su_user');
my $message;

my $template;
my $projectname = $cgi->param("project");
my $templatedir = $vhffs->get_config->get_templatedir;

Vhffs::Panel::Main::check( $vhffs );


#We try to know if an admin want to su
if( defined $su_user )
{
	if( $user->is_admin == 1 )
	{
		my $user_bis = new Vhffs::User( $vhffs , $su_user , '401' );
		if( defined( $user_bis ) && ( $user_bis->fetch > 0 ) )
		{
			$user = undef;
			$user = $user_bis;
            $session->clear("username");
            $session->clear("uid");
            $session->param("username", $user_bis->get_username);
            $session->param("uid", $user_bis->get_uid);
			$session->flush();
			$panel = new Vhffs::Panel::Main();
			$message = gettext( sprintf( "Su successfull with name %s " , $su_user) );
		}
		else
		{
			$message = sprintf( gettext( "User %s does not exists" ) , $su_user  );
		}
	}
	else
	{
		$message = gettext( "You're not an administrator" );
	}
}



if( defined $su_user )
{
	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	$template->param( MESSAGE => $message );
}
else
{
	if( defined $projectname )
	{
		$template = project_info Vhffs::Panel::Main($vhffs , $session , $user);
	}
	else
	{
		$template = right_first Vhffs::Panel::Main($vhffs , $session , $user);
	}
}

display Vhffs::Panel::Main($panel, $template->output);

