#!/usr/bin/perl -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;

use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;

my $panel = new Vhffs::Panel::Main();
if(!$panel)  {
        exit 0;
}

my $vhffs = $panel->{'vhffs'};
my $session = $panel->{'session'};
my $maintemplate = $panel->{'template'};
my $user = $panel->{'user'};
my $group = $panel->{'group'};
my $projectname = $session->param("project");
my $cgi = $panel->{'cgi'};
my $dbname = $cgi->param("name");
my $template;
my $message;
my $pgsql = new Vhffs::Services::Postgres( $vhffs , $dbname , $user , $group );

my $templatedir = $vhffs->get_config->get_templatedir;

if( $pgsql->fetch < 0 )
{

	my $template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	$message = gettext( "Cannot get informations on this object");
	$template->param( MESSAGE => $message );

}
elsif( Vhffs::Acl::what_perm_for_user( $user , $pgsql , $vhffs ) < Vhffs::Constants::ACL_VIEW )
{
	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
    $message = gettext("You're not allowed to do this (ACL rights)");
    $template->param( MESSAGE => $message );	
}
elsif( $pgsql->get_status != Vhffs::Constants::ACTIVATED )
{
    $template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
    $message = gettext("Please wait modification, creation or deletion");
    $template->param( MESSAGE => $message );
}
else
{
	$template = new HTML::Template( filename => $templatedir."/pgsql/prefs.tmpl" );

	$template->param( TEXT_TITLE => gettext("PostgreSQL Administration") );

	$template->param( TEXT_DBNAME => gettext("Name of the database") );
	$template->param( VALUE_DBNAME => $pgsql->get_dbname );

	$template->param( TEXT_DBUSER => gettext("Username for this database") );
	$template->param( VALUE_DBUSER => $pgsql->get_dbusername );

	$template->param( TEXT_DBPASS => gettext("Password for this database") );
#	$template->param( VALUE_DBPASS => $pgsql->get_dbpassword );
	
	$template->param( TEXT_ACL_ADMIN => "Admin Rights on this object (ACL)" );
	$template->param( EXPLAIN_ADMIN_ACL => "You can Manage rights on this service for each user in the VHFFS database. Please read help before manage it." );
	$template->param( ADMIN_ACL => "Ok, go to ACL admin" );

	$template->param( TEXT_SEND => gettext("Modify") );
	$template->param( TEXT_DELETE_PGSQL => gettext("Delete this PostgreSQL database") );
	$template->param( TEXT_BEFORE_DELETE => gettext("This action is non-reversible. All services associated to this project will be DESTROYED.") );
	$template->param( ASK_DELETE_PGSQL => gettext("Are you SURE you want DELETE this PostgreSQL database ?") );
	$template->param( YES => gettext("Yes I'm sure of what I do") );
	$template->param( NO => gettext("No, I'm not sure, I prefer to keep this project.") );
	$template->param( TEXT_DELETE => gettext("Delete") );
}

display Vhffs::Panel::Main($panel, $template->output);
