#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;

use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Acl;
use Vhffs::Constants;
use Vhffs::Panel::Main;
use Vhffs::Functions;

my $vhffs = init Vhffs::Main;
my $cookie = Vhffs::Panel::Main::cookie_lang( $vhffs );
my $template;
my $subtemplate;
my $templatedir = $vhffs->get_config->get_templatedir;
my $cgi = new CGI;
my $repos;
my $files;
my $objs;

my $name = $cgi->param("name");
$name = Vhffs::Functions::check_arg( $name );


my $group;
my $message;

if( ! defined $name )
{
	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	$message = gettext( "CGI ERROR!");
	$template->param( MESSAGE => $message );
}
elsif( ( ! defined ($group= new Vhffs::Group( $vhffs , $name , '401' ) ) ) || ( $group->fetch < 0 ))
{

	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	$message = gettext( "No such group");
	$template->param( MESSAGE => $message );

}
else
{
	$template = new HTML::Template( filename => $templatedir."/public/group.tmpl" );
	$template->param( THEME => Vhffs::Panel::Main::get_theme( $vhffs ) );
	$template->param( TEXT_TITLE => $group->get_groupname );

	$template->param( TEXT_GROUPNAME => gettext("Groupname") );
	$template->param( TEXT_DESCRIPTION => gettext("Description") );
	$template->param( VALUE_GROUPNAME => $group->get_groupname );
	$template->param( VALUE_DESCRIPTION => $group->get_description );
	$template->param( TEXT_USERS => gettext("Users") );

	
	my $output = "";
	my $users = $group->get_users;
	my $subtemplate;
	my $user;
	if( ! defined $users )
	{
		$template->param( VALUE_USERS => gettext("No group for this user") );
	}
	else
	{
		$subtemplate = new HTML::Template( filename => $templatedir."/public/user_part.tmpl" );
		
		foreach $user (@{$users})
		{
			$subtemplate->param( VALUE => $user->get_username );	
			$output .= $subtemplate->output;
		}

		$template->param( VALUE_USERS => $output );

		if( $vhffs->get_config->use_web == 1 )
		{

		    use Vhffs::Services::Httpd;

		    $output = "";
		    my $webs = Vhffs::Services::Httpd::getall_by_group( $vhffs , $group );
		    $template->param( WEBSITES_TITLE => gettext("Website for this group"));
		    if( defined $webs )
		    {
			foreach( @{$webs} )
			{
			    $subtemplate = new HTML::Template( filename => $templatedir."/public/misc/web-part.tmpl" );
			    $subtemplate->param( SERVERNAME => $_->get_servername );
			    $subtemplate->param( DESCRIPTION => $_->get_description );
			    $output .= $subtemplate->output;
			}

			$template->param( WEBSITES_VALUE => $output );
		    }
		    else
		    {
			$template->param( WEBSITES_VALUE => gettext("No website available for this group") );
		    }
		}

		if( $vhffs->get_config->use_cvs == 1 )
		{
		    use Vhffs::Services::Cvs;
		    $repos = Vhffs::Services::Cvs::getall_per_group( $vhffs , $group );
		    $output = "";
		    $template->param( CVS_TITLE => gettext("CVS repository for this group"));
		    if( defined $repos )
		    {
			foreach(  @{$repos} )
			{
			    $subtemplate = new HTML::Template( filename => $templatedir."/public/misc/cvs-part.tmpl" );
			    $subtemplate->param( CVSROOT => $_->get_cvsroot );
			    $subtemplate->param( CVSURL  => $vhffs->get_config->get_cvsweburl . "/" . $group->get_groupname . "/" . $_->get_cvsroot );
			    $output .= $subtemplate->output;
			}

			$template->param( CVS_VALUE => $output );
		    }
		    else
		    {
			$template->param( CVS_VALUE => gettext("No cvs repository available for this group") );
		    }
		}



		if( $vhffs->get_config->use_svn == 1 )
		{
		    use Vhffs::Services::Svn;
		    $repos = Vhffs::Services::Svn::getall_by_group( $vhffs , $group );
		    $output = "";
		    $template->param( SVN_TITLE => gettext("SVN repository for this group"));
		    if( defined $repos )
		    {
				foreach(  @{$repos} )
				{
			   	 	$subtemplate = new HTML::Template( filename => $templatedir."/public/misc/svn-part.tmpl" );
			    	$subtemplate->param( SVNROOT => $_->get_reponame );
			    	$subtemplate->param( DESCRIPTION => $_->get_description );
			    	$subtemplate->param( SVNURL  => $vhffs->get_config->get_svnweburl . "/listing.php?repname=".$_->get_reponame."+(".$group->get_groupname.")" );
			    	$output .= $subtemplate->output;
				}

				$template->param( SVN_VALUE => $output );
		    }
	    	else
	    	{
				$template->param( SVN_VALUE => gettext("No subversion repository available for this group") );
	    	}
		}



		if( $vhffs->get_config->use_largefile == 1 )
		{
		    use Vhffs::Services::LargeFile;
		    $files = Vhffs::Services::LargeFile::getall_by_group( $vhffs , $group );
		    $output = "";
		    $template->param( LARGEFILE_TITLE => gettext("Hosted files for this group"));
		    if( defined $files )
		    {
				foreach(  @{$files} )
				{
			   	 	$subtemplate = new HTML::Template( filename => $templatedir."/public/misc/largefile-part.tmpl" );
			    	$subtemplate->param( FILENAME => $_->get_filename );
			    	$subtemplate->param( TYPE => $_->get_type );
			    	$subtemplate->param( LICENCE => $_->get_description );
					$subtemplate->param( DOWNLOAD  => "Download this file" );
					$subtemplate->param( GROUPNAME  => $_->get_group->get_groupname );
			    	$output .= $subtemplate->output;
				}

				$template->param( LARGEFILE_VALUE => $output );
		    }
	    	else
	    	{
				$template->param( LARGEFILE_VALUE => gettext("No file available for this group") );
	    	}
		}

		if( $vhffs->get_config->use_mailing == 1 )
		{
			use Vhffs::Services::Mailing;
			$objs = Vhffs::Services::Mailing::getall_by_group( $vhffs , $group );
			$output = "";
		    $template->param( LISTS_TITLE => gettext("List(s) for this group") );
			if( defined $objs )
			{
				foreach(  @{$objs} )
				{
			   	 	$subtemplate = new HTML::Template( filename => $templatedir."/public/misc/list-part.tmpl" );
			    	$subtemplate->param( LISTNAME => $_->get_title );
			    	$subtemplate->param( ARCHIVESURL => $vhffs->get_config->get_www_archives );
			    	$subtemplate->param( ARCHIVES_TEXT => gettext( "View archives" ) );
			    	$output .= $subtemplate->output;
				}
				$template->param( LISTS_VALUE => $output );
			}
			else
			{
				$template->param( LISTS_VALUE => gettext("No list available for this group") );
			}
		}


	}
	$subtemplate = new HTML::Template( filename => $templatedir."/public/banner.tmpl" );
	$subtemplate->param( BACK_PUBLIC => gettext( "Homepage of public area") );
	$subtemplate->param( BACK_LOGIN => gettext( "Go on login page" ) );
	$subtemplate->param( WEBSITE_LIST => gettext( "List of all websites" ) );
	$subtemplate->param( LAST_GROUPS => gettext( "Last groups" ) );
	$subtemplate->param( LAST_USERS => gettext( "Last users" ) );
	$subtemplate->param( SEARCH => gettext( "Search:" ) );
	$template->param( BANNER => $subtemplate->output );
}
print "Content-Type: text/html; charset=utf-8\n\n" . $template->output;


