#!/usr/bin/perl -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

# subscribe.pl
# Handle subscription for VHFFS
# If the subscribe form has been submitted
# we try to create the user, else display
# the form. If there is an error we inform the
# user and redisplay the form (already filled)
#

use POSIX qw(locale_h);
use CGI;
use locale;
use Locale::gettext;
use HTML::Template;

use Vhffs::User;
use Vhffs::Main;
use Vhffs::Functions;
use Vhffs::Constants;
use Vhffs::Panel::Main;
use Vhffs::Panel::Confirmation;

#Get some basics informations with CGI
my $cgi;
my $uid;
my $good_news;
my $vhffs;
my $templatedir;
my $cid;
my $realcode;
my $code;

$cgi = new CGI;

#Initialize vars
$good_news = "";

#Init the Vhffs Main System
$vhffs = init Vhffs::Main;
$templatedir = $vhffs->get_config->get_templatedir;

Vhffs::Panel::Main::check( $vhffs );
Vhffs::Panel::Main::cookie_lang( $vhffs );


$submitted	= $cgi->param( "CREATE_SUBMIT" );
$mail 		= $cgi->param( "MAIL" );
$username 	= $cgi->param( "USERNAME" );
$firstname 	= $cgi->param( "FIRSTNAME");
$lastname 	= $cgi->param( "LASTNAME" );
$city 		= $cgi->param("CITY");
$zipcode 	= $cgi->param("ZIPCODE");
$country 	= $cgi->param("COUNTRY");
$address 	= $cgi->param("ADDRESS");
$cid 		= $cgi->param("CID");
$code 		= $cgi->param("CONFIRMATION");
$realcode	= Vhffs::Panel::Confirmation::get_code( $vhffs , $cid );

my $template;
my $message;

if( $vhffs->get_config->get_allow_subscribe == 0 )
{
# Subscribe isn't allow, inform user
        $template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl");
        $template->param( MESSAGE => gettext("You cannot subscribe to VHFFS") );
} elsif( defined $submitted ) {
# don't check if form hasn't been submitted
	@errors = ();
	if( ( ! defined $cid ) || ( ! defined $code ) || ( $code ne $realcode ) )
	{
		push(@errors, {error => gettext("Codes do not match")});
	}
	if( ! defined $username )
	{
		push(@errors, {error => gettext("You must declare your username")});
	}
	if( ( length ( $username ) < 3 ) || ( length ( $username ) > 12 ) )
	{
		push(@errors, {error => gettext("Username must contain between 3 and 12 characters")});
	}
	if( ! defined $country )
	{
		push(@errors, {error => gettext("You must declare your country")});
	}
	if( ! defined $city )
	{
		push(@errors, {error => gettext("You must declare your city")});
	}
	if( ! defined $zipcode )
	{
		push(@errors, {error => gettext("You must declare your zipcode")});
	}
	if( ! defined $firstname )
	{
		push(@errors, {error => gettext("You must declare your firstname")});
	}
	if( ! defined $lastname )
	{
		push(@errors, {error => gettext("You must declare your lastname")});
	}
	if( ( ! defined $mail ) || ( length( $mail ) < 6 ) )
	{
		push(@errors, {error => gettext("You must declare your mail address")});
	}
	if( Vhffs::Functions::valid_mail( $mail ) == -1 )
	{
		push(@errors, {error => gettext("You must declare a valid mail address")});
	}
	if( ! ( $zipcode =~ /^[\w\d\s\-]+$/ ) )
	{
		push(@errors, {error => gettext("Your zipcode is not correct! Please enter a correct zipcode")});
	}
	if( ! ( $firstname =~ /^[\w\d\s\-]+$/ ) )
	{
                push(@errors, {error => gettext("Please enter a correct firstname")});
	}
	if( ! ( $lastname =~ /^[\w\d\s\-]+$/ ) )
	{
                push(@errors, {error => gettext("Please enter a correct lastname")});
	}
	if( ! ( $city =~ /^[^(\(\)\\\.\_\e\'\")]+$/ ) )
	{
                push(@errors, {error => gettext("Please enter a correct city")});
	}
	if( ! ( $country =~ /^[\w\d\s\-\s]+$/ ) )
	{
            push(@errors, {error => gettext("Please enter a correct country")});
	}

	if( ( scalar @errors )  == 0)
	{
	    my $retour;
	    my $user = new Vhffs::User( $vhffs , $username , '401' );
	    if( defined $user )
	    {
		$uid = $user->create;
		
		if( $uid < 0 )
		{
		    #If the API returns a negative value as uid, the user cannot be created !
		    push( @errors, {error => gettext("Cannot create user, the username you entered already exists")});
		}
		else
		{
		    #Get user information
		    $user->fetch;
		    
		    #We set informations user fill in the form
		    $user->set_mail( $mail );
		    $user->set_firstname( $firstname );
		    $user->set_lastname( $lastname );
		    $user->set_city( $city );
		    $user->set_zipcode( $zipcode );
		    $user->set_country( $country );
		    $user->set_address( $address );
		    $user->set_status( Vhffs::Constants::WAITING_FOR_CREATION );
		    $user->set_password( Vhffs::Functions::generate_random_password );			
		    
		    #Commit all the changes for the current user
		    if( ( $retour = $user->commit ) < 0 )
		    {
			push ( @errors, { error => gettext("Cannot apply changes to the user") } );
		    }
		    else
		    {
			$good_news = gettext("User Successfully created");
			$good_news2 = gettext("Please wait while we are creating the account, it will take some minutes");
			$template = new HTML::Template( filename => $templatedir."/user/create_complete.tmpl" );
	    		$template->param( TEXT_BACK => gettext("Back to Login") );
			$template->param( GOOD_NEWS => $good_news );
			$template->param( GOOD_NEWS2 => $good_news2 );
		    }
		}
		
	    } else {
		push ( @errors, { error => gettext("Cannot create user. Your username should contain at least 3 characters which are only lower case and digits.") } );
	    }
	}
	if ( ( scalar @errors ) > 0 ) {
	    $template = new HTML::Template( filename => $templatedir."/user/create.tmpl" );
	    # There was an error, fill the template parameter
	    $template->param( ERRORS => \@errors );
	    $template->param( USERNAME_VALUE         => $username );
	    $template->param( MAIL_VALUE             => $mail );
	    $template->param( FIRSTNAME_VALUE        => $firstname );
	    $template->param( LASTNAME_VALUE         => $lastname );
	    $template->param( ZIPCODE_VALUE          => $zipcode );
	    $template->param( CITY_VALUE             => $city );
	    $template->param( COUNTRY_VALUE          => $country );
	    $template->param( ADDRESS_VALUE          => $address );

	}
} else {
    $template = new HTML::Template( filename => $templatedir."/user/create.tmpl" );
}

if( ( ! defined $submitted ) || ( ( defined @errors) && ( (scalar @errors) != 0 ) ) ) {
    $confirmation  = Vhffs::Panel::Confirmation::create_code( $vhffs );

# $template is defined in every cases

    $template->param( TEXT_SUBSCRIBE        => gettext("Subscription") );
    $template->param( TEXT_INFOS            => gettext("Please fill in all fields, a mail containing your password will be sent to you") );
    $template->param( USERNAME_TEXT         => gettext("Username") );
    $template->param( MAIL_TEXT             => gettext("mail") );
    $template->param( FIRSTNAME_TEXT        => gettext("Firstname") );
    $template->param( LASTNAME_TEXT         => gettext("Lastname") );
    $template->param( ZIPCODE_TEXT          => gettext("Zipcode") );
    $template->param( CITY_TEXT             => gettext("City") );
    $template->param( COUNTRY_TEXT          => gettext("Country") );
    $template->param( ADDRESS_TEXT          => gettext("Address") );
    $template->param( SEND                  => gettext("Subscribe") );
    $template->param( BACK                  => gettext("Back to Login") );
    $template->param( CONFIRMATION_TEXT     => gettext("Code confirmation") );
    $template->param( REPEAT_CONFIRMATION_TEXT      => gettext("Recopy the code") );
    $template->param( CID                   => $confirmation->[0] );

}
$template->param( TITLE => gettext("Subscribe") );

display_light Vhffs::Panel::Main( $vhffs , $template );
