#!/usr/bin/perl -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;

use Vhffs::User;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Panel::User;

my $panel = new Vhffs::Panel::Main();
if(!$panel)  {
        exit 0;
}

my $vhffs = $panel->{'vhffs'};
my $session = $panel->{'session'};
my $maintemplate = $panel->{'template'};
my $user = $panel->{'user'};

my $mailuser;

if( $vhffs->get_config->use_mailuser == 1 )
{
	$mailuser = 1;
}
else
{
	$mailuser = 0;
}

my $username = $user->get_username();
my $usermail = $user->get_mail();

my $templatedir = $vhffs->get_config->get_templatedir;

my $template = new HTML::Template( filename => $templatedir."/user/prefs.tmpl" );

$template->param( TEXT_TITLE => gettext("User Preferences") );

$template->param( TEXT_USERNAME => gettext("Username") );
$template->param( TEXT_MAIL => gettext("mail") );
$template->param( TEXT_FIRSTNAME => gettext("Firstname") );
$template->param( TEXT_LASTNAME => gettext("Lastname") );
$template->param( TEXT_ZIPCODE => gettext("Zipcode") );
$template->param( TEXT_CITY => gettext("City") );
$template->param( TEXT_ADDRESS => gettext("Address") );
$template->param( TEXT_COUNTRY => gettext("Country") );
$template->param( TEXT_PASSWORD1 => gettext("Password") );
$template->param( TEXT_PASSWORD2 => gettext("Confirm Password") );
$template->param( TEXT_LANG => gettext("Language") );
$template->param( TEXT_THEME => gettext("Theme") );
$template->param( TEXT_SEND => gettext("Modify") );

$template->param( VALUE_USERNAME => $user->get_username ); 
$template->param( VALUE_MAIL => $user->get_mail ); 
$template->param( VALUE_FIRSTNAME => $user->get_firstname ); 
$template->param( VALUE_LASTNAME => $user->get_lastname ); 
$template->param( VALUE_ZIPCODE => $user->get_zipcode ); 
$template->param( VALUE_CITY => $user->get_city ); 
$template->param( VALUE_ADDRESS => $user->get_address ); 
$template->param( VALUE_COUNTRY => $user->get_country ); 

$template->param( TEXT_DELETE_USER => gettext("Delete YOUR user") );
$template->param( TEXT_BEFORE_DELETE => gettext("This action is non-reversible. WHEN YOU DELETE IT, YOU CANNOT CANCEL.") );
$template->param( ASK_DELETE_USER => gettext("Are you SURE you want DELETE this user?") );
$template->param( YES => gettext("Yes I'm sure of what I do") );
$template->param( NO => gettext("No, I'm not sure, I prefer to keep it.") );
$template->param( TEXT_DELETE => gettext("Delete") );

if( $vhffs->get_config->get_panel_avatar() )  { 

	my $ta = new HTML::Template( filename => $templatedir."/user/prefs_avatar.tmpl" );

	$ta->param( SEND_AVATAR => gettext("Send my avatar") );
	$ta->param( CURRENT_AVATAR => gettext("Current avatar") );
	$ta->param( TEXT_AVATAR => gettext("Send my avatar") );
	$ta->param( EXPLAIN_AVATAR => gettext("The avatar is a pictures that describes you. You can upload an PNG image and use it as avatar. This image will then appear in the public section.") );
	$ta->param( VALUE_OID => $user->get_oid ); 

	$template->param( AVATAR => $ta->output );
}


# themes

my @themes = Vhffs::Panel::Main::list_themes( $vhffs );
my $curtheme = Vhffs::Panel::User::get_theme( $user );
my $themelist;
foreach( @themes )
{
	if($curtheme ne $_)
	{
		$themelist .= "<option value=\"".$_."\">".$_."</option>\n";
	}
	else
	{
		$themelist .= "<option value=\"".$_."\" selected=\"selected\">".$_."</option>\n";
	}
}
$template->param( THEME_LIST => $themelist );


# languages

my @langs = Vhffs::Panel::Main::list_languages( $vhffs );
my $curlang = Vhffs::Panel::User::get_lang( $user );
my $langlist;
foreach( @langs )
{
	if($curlang ne $_)
	{
		$langlist .= "<option value=\"".$_."\">".$_."</option>\n";
	}
	else
	{
		$langlist .= "<option value=\"".$_."\" selected=\"selected\">".$_."</option>\n";
	}
}
$template->param( LANG_LIST => $langlist );

if( $mailuser == 1 )
{
	use Vhffs::Services::MailUser;
    
	my $subtemplate = new HTML::Template( filename => $templatedir."/user/mailuser.tmpl" );
	my $subtemplate2;
	my $config = $vhffs->get_config->get_service( "mailuser" );
	my $mu  = init Vhffs::Services::MailUser( $vhffs , $user );
	my $tmp = "";

	if( defined $mu  &&  $mu >= 0  &&  $mu->available > 0 )
	{
    
    $subtemplate->param( ACTIV_CHECKED => "checked" ) if( $mu->exists == 1         );
    $subtemplate->param( POP_CHECKED => "checked" )   if( $mu->exists_box == 1     );
    $subtemplate->param( FWD_CHECKED => "checked" )   if( $mu->exists_forward == 1 );   
    $subtemplate->param( TEXT_MAILACTIV => sprintf( gettext("Activate %s\@%s email"), $username, $config->{domain}) );
    $subtemplate->param( TEXT_MAILINFO1 => sprintf( gettext("We offer you the possibility to have one email box on the domain %s") , $config->{domain}) );
    $subtemplate->param( TEXT_MAILINFO2 => gettext("There is two possible usages :") );
    $subtemplate->param( TEXT_MAILBOX => sprintf( gettext("Use VHFFS servers to manage this mail,<br>you should use use the host pop.%s or imap.%s to fetch your mails") , $config->{domain} , $config->{domain} ) );
    $subtemplate->param( TEXT_MAILFORWARD => sprintf( gettext("Forward emails from %s\@%s to %s"), $username, $config->{domain}, $usermail ) );

	if( $vhffs->get_config->use_nospam == 1 )
	{
	    $subtemplate2 = new HTML::Template( filename => $templatedir."/user/mailuserspam.tmpl" );
	    $subtemplate2->param( TEXT_NOSPAM => gettext("Use anti-spam protection") );
	    $subtemplate2->param( ACTIV_CHECKED => "checked" ) if( $mu->use_nospam == 1         );
		$tmp .= $subtemplate2->output;
	}

	if( $vhffs->get_config->use_novirus == 1 )
	{
    	$subtemplate2 = new HTML::Template( filename => $templatedir."/user/mailuservirus.tmpl" );
	    $subtemplate2->param( TEXT_VIRUS => gettext("Use anti-virus protection") );
	    $subtemplate2->param( ACTIV_CHECKED => "checked" ) if( $mu->use_novirus == 1         );
		$tmp .= $subtemplate2->output;
	}

    
    $subtemplate->param( MAILUSER_OPTIONS => $tmp );
    $template->param( MAILUSER => $subtemplate->output );
	}
    
}

display Vhffs::Panel::Main($panel, $template->output);
