#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

use POSIX qw(locale_h);
use locale;
use Locale::gettext;
use strict;
use Vhffs::Main;
use Vhffs::User;
use Vhffs::Group;
use Vhffs::Robots;
use Vhffs::Robots::Group;
use Vhffs::Panel::User;


my $vhffs;
my $user;
my $message;
my $subject;
my $object;
my $lang;
my $objects;

$vhffs = init Vhffs::Main;

Vhffs::Robots::lock( $vhffs );

$objects = Vhffs::Group::getall( $vhffs , Vhffs::Constants::VALIDATION_REFUSED );
bindtextdomain("vhffs", $vhffs->get_config->get_intldir);
textdomain("vhffs");

foreach $object ( @{$objects} )
{
	if( ( defined $object ) && ( $object->fetch > 0 ) )
	{
		$user = $object->get_user;
		$lang = Vhffs::Panel::User::get_lang( $user );
		setlocale( LC_ALL , $lang ) if( defined $lang );
		if( $user->fetch > 0 )
		{
			$message  = sprintf( gettext("Your Group request : %s ") , $object->get_groupname);
			$message .= gettext("has been refused by the Moderators team")."\n";
			$message .= gettext("In hope to keep you in our hosting service")."\n\n";
			if( length( $object->get_description ) > 1 )
			{
			    $message .= gettext("Reason given : ");
			    $message .= $object->get_description . "\n";
			}
			$message .= sprintf( gettext("If you encounters problem, please mail: %s\n") , $vhffs->get_config->get_moderator_mail ) if( defined $vhffs->get_config->get_moderator_mail );
			$message .= gettext("Cheers,")."\n";
			$message .= gettext("The Moderator and Admin team");

			$subject = gettext("Your Group request");
			Vhffs::Functions::send_mail( $vhffs->get_config->get_moderator_mail , $user->get_mail , $subject , $message );
		}
		
		$object->delete;
	}
}


Vhffs::Robots::unlock( $vhffs );
exit 0;
