#!/usr/bin/perl

use strict;
use POSIX qw(locale_h);
use locale;
use Locale::gettext;
use Vhffs::Main;
use Vhffs::User;
use Vhffs::Group;
use Vhffs::Robots;
use Vhffs::Services::Mysql;
use Vhffs::Panel::User;


my $vhffs;
my $user;
my $message;
my $subject;
my $object;
my $lang;
my $objects;

$vhffs = init Vhffs::Main;

Vhffs::Robots::lock( $vhffs );

$objects = Vhffs::Services::Mysql::getall( $vhffs , Vhffs::Constants::VALIDATION_REFUSED );
bindtextdomain("vhffs", $vhffs->get_config->get_intldir);
textdomain("vhffs");

foreach $object ( @{$objects} )
{
	if( ( defined $object ) && ( $object->fetch > 0 ) )
	{
		$user = $object->get_user;
		$lang = Vhffs::Panel::User::get_lang( $user );
		setlocale( LC_ALL , $lang ) if( defined $lang );
		if( $user->fetch > 0 )
		{
			$message  = sprintf( gettext("Your MySQL database request : %s ") , $object->get_dbname );
			$message .= gettext("has been refused by the Moderators team")."\n";
			$message .= gettext("In hope to keep you in our hosting service")."\n\n";
			if( length( $object->get_description ) > 1 )
			{
			    $message .= gettext("Reason given : ");
			    $message .= $object->get_description . "\n";
			}
			$message .= sprintf( gettext("If you encounters problem, please mail: %s\n") , $vhffs->get_config->get_moderator_mail ) if( defined $vhffs->get_config->get_moderator_mail );
			$message .= gettext("Cheers,")."\n";
			$message .= gettext("The Moderator and Admin team");

			$subject = gettext("Your MySQL database request");
			Vhffs::Functions::send_mail( $vhffs->get_config->get_moderator_mail , $user->get_mail , $subject , $message );
		}
		
		$object->delete;
	}
}



Vhffs::Robots::unlock( $vhffs );
exit 0;
